﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 포인트 시리즈
        /// </summary>
        private Points points;

        /// <summary>
        /// 경계 함수
        /// </summary>
        private PerimeterFunction perimeterFunction;

        /// <summary>
        /// 라인 시리즈
        /// </summary>
        private Line line;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 포인트 시리즈를 생성한다.

            this.points = new Points();

            this.points.Title               = "points";
            this.points.Pointer.Brush.Color = Color.FromArgb(254, 0, 0, 255);
            this.points.Pointer.Style       = PointerStyles.Rectangle;

            #endregion
            #region 경계 함수를 생성한다.

            this.perimeterFunction = new PerimeterFunction();

            #endregion
            #region 라인 시리즈를 생성한다.

            this.line = new Line();

            this.line.Title         = "Perimeter";
            this.line.Color         = Color.Red;
            this.line.LinePen.Width = 2;
            this.line.DataSource    = this.points;
            this.line.Function      = this.perimeterFunction;

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Series.Add(this.points);
            this.tChart.Series.Add(this.line);

            #endregion

            this.points.FillSampleValues();

            this.refreshButton.Click += refreshButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 갱신하기 버튼 클릭시 처리하기 - refreshButton_Click(sender, e)

        /// <summary>
        /// 갱신하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void refreshButton_Click(object sender, EventArgs e)
        {
            this.points.FillSampleValues();
        }

        #endregion
    }
}